@@ -20,7 +20,7 @@ use POE;
 use aliased 'POE::Kernel' => 'K';
 
 # Public variables of the module.
-our $VERSION = '1.1.0';
+our $VERSION = '1.1.1';
 
 use base qw{ Class::Accessor::Fast };
 __PACKAGE__->mk_accessors( qw{
@@ -78,6 +78,31 @@ sub cards_reset {
 }
 
 
+#
+# $game->destroy;
+#
+# Break all circular references in $game, to reclaim all objects
+# referenced.
+#
+sub destroy {
+    my ($self) = @_;
+
+    # breaking players (& ais) references
+    $_->destroy for $self->players;
+    $self->curplayer(undef);
+    $self->_players([]);
+    $self->_players_active([]);
+    $self->_players_turn_done([]);
+    $self->_players_turn_todo([]);
+
+    # breaking map (& countries & continents) references
+    $self->map->destroy;
+    $self->map(undef);
+    $self->src(undef);
+    $self->dst(undef);
+}
+
+
 #
 # $game->player_lost( $player );
 #
@@ -289,6 +314,12 @@ the current C<Games::Risk::Map> object of the game.
 Put back all cards given to players to the deck.
 
 
+=item * $game->destroy;
+
+Break all circular references in C<$game>, to reclaim all objects
+referenced.
+
+
 =item * $game->player_lost( $player )
 
 Remove $player from the list of active players.
