@@ -415,7 +415,15 @@ sub _onpub_quit {
 #
 sub _onpub_shutdown {
     my $h = $_[HEAP];
+
+    # remove all possible pending events.
+    K->alarm_remove_all;
+
+    # close all ais & windows
     $h->send_to_all('shutdown');
+
+    # remove all circular references
+    $h->destroy;
 }
 
 
